ActorTestBuilder

Struct ActorTestBuilder 

pub struct ActorTestBuilder<S: Send + 'static> { /* private fields */ }
This builder is used to build a TestActor.

Implementations

Source

impl<S: Send + 'static> ActorTestBuilder<S>

pub fn new(addr: Addr) -> Self

Creates a new ActorTestBuilder with some default settings which are needed to run tests.

pub fn check(self, check_fn: fn(&S) -> bool) -> Self

Adds the given check function to the test list. check_fn can immutably access the whole internal state of the actor to be tested.

pub fn tell<M: Any + Send>(self, msg: M) -> Self

Sends the given message to the actor to be tested.

pub fn ask<M: Any + Send, R: Any + Send>( self, msg: M, expected_response: Response<R>, ) -> Self

Sends the given message to the actor to be tested and automatically inserts the TestActor’s address into the reply_to field. Further an expected Response has to be defined which is also checked.

pub fn expect_tell<M: Any + Send>(self, criteria: fn(M) -> bool) -> Self

This function defines that a tell-message is to be received next with the given condition. If no specific condition is required a simple |msg| true can be passed in.

pub fn expect_ask<M: Any + Send>(self, criteria: fn(M) -> bool) -> Self

This function defines that an ask-message is to be received next with the given condition. If no specific condition is required a simple |msg| true can be passed in.

pub fn build(self) -> Actor<TestActor<S>>

Consumes the builder and generates an Actor which represents the defined testing behavior.