pub struct ActorTestBuilder<S: Send + 'static> { /* private fields */ }Expand description
This builder is used to build a TestActor.
Implementations
Sourceimpl<S: Send + 'static> ActorTestBuilder<S>
impl<S: Send + 'static> ActorTestBuilder<S>
Sourcepub fn new(addr: Addr) -> Self
pub fn new(addr: Addr) -> Self
Creates a new ActorTestBuilder with some default settings which are needed to run tests.
Sourcepub fn check(self, check_fn: fn(&S) -> bool) -> Self
pub fn check(self, check_fn: fn(&S) -> bool) -> Self
Adds the given check function to the test list. check_fn can immutably access the whole internal state of the actor to be tested.
Sourcepub fn tell<M: Any + Send>(self, msg: M) -> Self
pub fn tell<M: Any + Send>(self, msg: M) -> Self
Sends the given message to the actor to be tested.
Sourcepub fn ask<M: Any + Send, R: Any + Send>(
self,
msg: M,
expected_response: Response<R>,
) -> Self
pub fn ask<M: Any + Send, R: Any + Send>( self, msg: M, expected_response: Response<R>, ) -> Self
Sourcepub fn expect_tell<M: Any + Send>(self, criteria: fn(M) -> bool) -> Self
pub fn expect_tell<M: Any + Send>(self, criteria: fn(M) -> bool) -> Self
This function defines that a tell-message is to be received next with the given condition. If no specific condition is required a simple |msg| true can be passed in.